==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForDatabasesGcpOfferingConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Configuration for servers Arc auto provisioning
 * @property privateLinkScope Optional Arc private link scope resource id to link the Arc agent
 * @property proxy Optional http proxy endpoint to use for the Arc agent
 */
public data class DefenderForDatabasesGcpOfferingConfigurationArgs(
    public val privateLinkScope: Output<String>? = null,
    public val proxy: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs =
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs.builder()
            .privateLinkScope(privateLinkScope?.applyValue({ args0 -> args0 }))
            .proxy(proxy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForDatabasesGcpOfferingConfigurationArgs].
 */
@PulumiTagMarker
public class DefenderForDatabasesGcpOfferingConfigurationArgsBuilder internal constructor() {
    private var privateLinkScope: Output<String>? = null

    private var proxy: Output<String>? = null

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("inlsoshbagpodewj")
    public suspend fun privateLinkScope(`value`: Output<String>) {
        this.privateLinkScope = value
    }

    /**
     * @param value Optional http proxy endpoint to use for the Arc agent
     */
    @JvmName("pjjrdenkibqbcsww")
    public suspend fun proxy(`value`: Output<String>) {
        this.proxy = value
    }

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("ntvscdjeawlhdemr")
    public suspend fun privateLinkScope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkScope = mapped
    }

    /**
     * @param value Optional http proxy endpoint to use for the Arc agent
     */
    @JvmName("xldtxmudndoovwji")
    public suspend fun proxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.proxy = mapped
    }

    internal fun build(): DefenderForDatabasesGcpOfferingConfigurationArgs =
        DefenderForDatabasesGcpOfferingConfigurationArgs(
            privateLinkScope = privateLinkScope,
            proxy = proxy,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/DefenderForDatabasesGcpOfferingConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Configuration for servers Arc auto provisioning
 * @property privateLinkScope Optional Arc private link scope resource id to link the Arc agent
 * @property proxy Optional http proxy endpoint to use for the Arc agent
 */
public data class DefenderForDatabasesGcpOfferingConfigurationArgs(
    public val privateLinkScope: Output<String>? = null,
    public val proxy: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs =
        com.pulumi.azurenative.security.inputs.DefenderForDatabasesGcpOfferingConfigurationArgs.builder()
            .privateLinkScope(privateLinkScope?.applyValue({ args0 -> args0 }))
            .proxy(proxy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefenderForDatabasesGcpOfferingConfigurationArgs].
 */
@PulumiTagMarker
public class DefenderForDatabasesGcpOfferingConfigurationArgsBuilder internal constructor() {
    private var privateLinkScope: Output<String>? = null

    private var proxy: Output<String>? = null

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("hialuutcchxnjlpo")
    public suspend fun privateLinkScope(`value`: Output<String>) {
        this.privateLinkScope = value
    }

    /**
     * @param value Optional http proxy endpoint to use for the Arc agent
     */
    @JvmName("gfeldbwttexjhfdc")
    public suspend fun proxy(`value`: Output<String>) {
        this.proxy = value
    }

    /**
     * @param value Optional Arc private link scope resource id to link the Arc agent
     */
    @JvmName("trijgqhwhxwgatlw")
    public suspend fun privateLinkScope(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkScope = mapped
    }

    /**
     * @param value Optional http proxy endpoint to use for the Arc agent
     */
    @JvmName("iirhppnkyiaoqsnx")
    public suspend fun proxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.proxy = mapped
    }

    internal fun build(): DefenderForDatabasesGcpOfferingConfigurationArgs =
        DefenderForDatabasesGcpOfferingConfigurationArgs(
            privateLinkScope = privateLinkScope,
            proxy = proxy,
        )
}
